display

package
v0.0.0-...-c3a30db Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 8, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateFileAndWrite

func CreateFileAndWrite(items ...model.Todo)

func DisplayConcurrent

func DisplayConcurrent()

func Print

func Print(out io.Writer, item string)

func PrintList

func PrintList(out io.Writer, listOfWork ...model.Todo)

func PrintListJSON

func PrintListJSON(out io.Writer, items ...model.Todo)

func ReadJsonFile

func ReadJsonFile(fileName string) string

Types

This section is empty.

Directories

Path Synopsis
used in display, not for cmdline or web app
used in display, not for cmdline or web app

Jump to